<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Slovenšcina [SL]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=453
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = 'slovenščina';
$lang_info['country'] = 'Slovenija';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'sl';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d kategorija popravljena';
$lang['%d albums updated'] = '%d kategorij popravljenih';
$lang['%d comment to validate'] = '%d komentar za preveriti';
$lang['%d comments to validate'] = '%d komentarjev za preveriti';
$lang['%d new comment'] = '%d novi komentar';
$lang['%d new comments'] = '%d novih komentarjev';
$lang['%d comment'] = '%d komentar';
$lang['%d comments'] = '%d komentarjev';
$lang['%d hit'] = '%d zadetek';
$lang['%d hits'] = '%d zadetkov';
$lang['%d new user'] = '%d novi uporabnik';
$lang['%d new users'] = '%d novih uporabnikov';
$lang['About'] = 'Vizitka';
$lang['All tags'] = 'Vse označbe';
$lang['Any tag'] = 'Katerakoli označba';
$lang['At least one listed rule must be satisfied.'] = 'Vsaj eno pravilo mora biti izpolnjeno.';
$lang['At least one tag must match'] = 'Vsaj ena označba se mora ujemati';
$lang['Author'] = 'Avtor';
$lang['Albums'] = 'Kategorije';
$lang['Album'] = 'Kategorija';
$lang['Close this window'] = 'Zapri okno';
$lang['Confirm Password'] = 'Potrdi geslo';
$lang['Connection settings'] = 'Nastavitve povezave';
$lang['Contact webmaster'] = 'Kontaktiraj skrbnika';
$lang['Create a new account'] = 'Ustvari nov račun';
$lang['Created on'] = 'Ustvarjeno';
$lang['Creation date'] = 'Ustvarjeno';
$lang['Current password is wrong'] = 'Napačno geslo';
$lang['Dimensions'] = 'Dimenzije';
$lang['Display'] = 'Zaslon';
$lang['%d new photo'] = '%d nova slika';
$lang['%d new photos'] = '%d novih slik';
$lang['Complete RSS feed (photos, comments)'] = 'RSS vir (slike, komentarji)';
$lang['Login'] = 'Prijava';
$lang['Each listed rule must be satisfied.'] = 'Vsa pravila morajo biti izpolnjena.';
$lang['Email address'] = 'E-pošta';
$lang['Enter your personnal informations'] = 'Vnesite svoje osebne podatke';
$lang['Error sending email'] = 'Napaka pri pošiljanju pošte';
$lang['File name'] = 'Ime datoteke';
$lang['File'] = 'Datoteka';
$lang['Filesize'] = 'Velikost datoteke';
$lang['Filter and display'] = 'Filter in prikaz';
$lang['Filter'] = 'Filter';
$lang['Forgot your password?'] = 'Si pozabil geslo?';
$lang['Go through the gallery as a visitor'] = 'Obiskaj galerijo kot obiskovalec';
$lang['Help'] = 'Pomoč';
$lang['Identification'] = 'Identifikacija';
$lang['Photos only RSS feed'] = 'RSS vir (samo slike)';
$lang['Keyword'] = 'Ključna beseda';
$lang['Links'] = 'Povezave';
$lang['N/A'] = 'N/A';
$lang['New on %s'] = 'Nov na %s';
$lang['New password confirmation does not correspond'] = 'Potrditveno geslo se ne ujema';
$lang['Notification'] = 'Obvestilo';
$lang['Number of items'] = 'Število ';
$lang['Original dimensions'] = 'Originalna velikost';
$lang['Password forgotten'] = 'Pozabljeno geslo';
$lang['Password'] = 'Geslo';
$lang['Post date'] = 'Datum objave';
$lang['Posted on'] = 'Objavljeno';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Hitra povezava';
$lang['RSS feed'] = 'RSS vir';
$lang['Register'] = 'Registracija';
$lang['Registration'] = 'Registracija';
$lang['Unknown feed identifier'] = 'Neznan identifikator vira';
$lang['User comments'] = 'Komentarji uporabnika';
$lang['Username'] = 'Uporabniško ime';
$lang['Visits'] = 'Obiski';
$lang['Webmaster'] = 'Skrbnik';
$lang['Week %d'] = 'Teden %d';
$lang['About Piwigo'] = 'O Piwigo';
$lang['You are not authorized to access the requested page'] = 'Niste avtorizirani za dostop do zahtevane strani';
$lang['add to caddie'] = 'dodaj med caddie';
$lang['add this photo to your favorites'] = 'dodaj sliko med svoje priljubljene';
$lang['Administration'] = 'Administracija';
$lang['all'] = 'vse';
$lang['ascending'] = 'naraščujoce';
$lang['author(s) : %s'] = 'avtor(ji) : %s';
$lang['Expand all albums'] = 'Razširi vse kategorije';
$lang['posted after %s (%s)'] = 'naloženo po %s (%s)';
$lang['posted before %s (%s)'] = 'naloženo pred %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'naloženo med %s (%s) in %s (%s)';
$lang['posted on %s'] = 'naloženo na %s';
$lang['Best rated'] = 'Najbolje ocenjene';
$lang['display best rated photos'] = 'prikaži najbolje ocenjene slike';
$lang['caddie'] = 'Caddie';
$lang['Calendar'] = 'Koledar';
$lang['All'] = 'Vse';
$lang['display each day with photos, month per month'] = 'prikaži slike po dnevih in mesecih'; 
$lang['View'] = 'Pogled';
$lang['chronology_monthly_calendar'] = 'Mesečni koledar';
$lang['chronology_monthly_list'] = 'Mesečni seznam';
$lang['chronology_weekly_list'] = 'Tedenski seznam';
$lang['Click here if your browser does not automatically forward you'] = 'Če vas brskalnik ni preusmeril, kliknite tukaj.';
$lang['comment date'] = 'komentarji po datumih';
$lang['Comment'] = 'Komentar';
$lang['Your comment has been registered'] = 'Vaš komentar je bil zabeležen';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood sistem : prosim počakajte trenutek, preden oddate nov komentar';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Vaš komentar ni bil zabeležen, saj ne ustreza validacijskim pravilom';
$lang['An administrator must authorize your comment before it is visible.'] = 'Administrator mora pregledati vaš komentar, preden le-ta postane viden.';
$lang['This login is already used by another user'] = 'Ta prijava je že uporabljena s strani drugega uporabnika';
$lang['Comments'] = 'Komentarji';
$lang['Add a comment'] = 'Dodaj komentar';
$lang['created after %s (%s)'] = 'kreirano po %s (%s)';
$lang['created before %s (%s)'] = 'kreirano pred %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'kreirano med %s (%s) in %s (%s)';
$lang['created on %s'] = 'kreirano na %s';
$lang['Customize'] = 'Prilagodi';
$lang['Your Gallery Customization'] = 'Prilagodi svojo galerijo';
$lang['Related tags'] = 'Sorodne označbe';
$lang['Reset'] = 'Ponastavi';
$lang['Retrieve password'] = 'Pridobi geslo';
$lang['Search rules'] = 'Iskalni kriteriji';
$lang['Search tags'] = 'Iskalne označbe';
$lang['Search'] = 'Išci';
$lang['display available tags'] = 'Prikaži možne označbe';
$lang['Since'] = 'Odkar';
$lang['Sort by'] = 'Uredi po';
$lang['Sort order'] = 'Urejeno po';
$lang['Tag'] = 'Označba';
$lang['Tags'] = 'Označbe';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS viri omogočajo prijavo na dogodke te spletne strani, kot so: nove slike, nove kategorije, novi komentarji. Za uporabo je potreben RSS odjemalec.';
$lang['Default'] = 'Privzeto';
$lang['delete this photo from your favorites'] = 'odstrani to sliko iz svojih priljubljenih';
$lang['Delete'] = 'Odstrani';
$lang['descending'] = 'padajoče';
$lang['download'] = 'snami';
$lang['download this file'] = 'snami to datoteko';
$lang['edit'] = 'uredi';
$lang['wrong date'] = 'napačen datum';
$lang['excluded'] = 'izključen';
$lang['Your favorites'] = 'Moje priljubljene';
$lang['display your favorites photos'] = 'prikaži moje priljubljene slike';
$lang['Favorites'] = 'Priljubljene';
$lang['First'] = 'Prva';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Stran je v vzdrževanju. Prosim, oglasite se kasneje.';
$lang['Page generated in'] = 'Stran naložena v';
$lang['guest'] = 'gost';
$lang['Hello'] = 'Pozdravljen';
$lang['available for administrators only'] = 'dovoljeno samo za administratorje';
$lang['display this album'] = 'prikaži slike na najvišjem nivoju te kategorije';
$lang['display last user comments'] = 'Prikaži zadnje komentarje uporabnika';
$lang['customize the appareance of the gallery'] = 'prilagodi izgled galerije';
$lang['search'] = 'išči';
$lang['Home'] = 'Domov';
$lang['in this album'] = 'v tej kategoriji';
$lang['in %d sub-album'] = 'v %d pod-kategoriji';
$lang['in %d sub-albums'] = 'v %d pod-kategorijah';
$lang['included'] = 'vsebuje';
$lang['Invalid password!'] = 'Napačno geslo!';
$lang['Language'] = 'Jezik';
$lang['last %d days'] = 'zadnjih %d dnevih';
$lang['Last'] = 'Zadnji';
$lang['Logout'] = 'Odjava';
$lang['E-mail address'] = 'E-pošta';
$lang['obligatory'] = 'obvezno';
$lang['Maximum photo height'] = 'Maksimalna velikost slik';
$lang['Maximum height must be a number superior to 50'] = 'Maksimalna velikost mora biti vecja od 50';
$lang['Maximum photo width'] = 'Maksimalna dolžina slik';
$lang['Most visited'] = 'Najbolj obiskana';
$lang['display most visited photos'] = 'prikaži najbolj obiskane slike';
$lang['The number of photos per page must be a not null scalar'] = 'Število slik na stran, mora biti ne prazno celo število.';
$lang['Number of photos per page'] = 'Število slik na stran';
$lang['Unknown identifier'] = 'Neznan';
$lang['New password'] = 'Novo geslo';
$lang['Rate this photo'] = 'Glasuj';
$lang['Next'] = 'Naprej';
$lang['no rate'] = 'brez glasa';
$lang['Photos posted within the last %d day.'] = 'Elementi naloženi znotraj zadnjega %d dneva.';
$lang['Photos posted within the last %d days.'] = 'Elementi naloženi znotraj zadnjih %d  dni.';
$lang['password updated'] = 'geslo spremenjeno';
$lang['Recent period must be a positive integer value'] = 'Novo obdobje more biti pozitivno celo število';
$lang['photo'] = 'slika';
$lang['Click on the photo to see it in high definition'] = 'Za ogled  v originalni velikosti, kliknite na sliko';
$lang['Show file metadata'] = 'Prikaži mete podatke datoteke';
$lang['Powered by'] = 'Narejeno z';
$lang['Preferences'] = 'Nastavitve';
$lang['Previous'] = 'Nazaj';
$lang['Random photos'] = 'Naključne slike';
$lang['display a set of random photos'] = 'prikaži množico nakljucno izbranih slik';
$lang['Recent albums'] = 'Nove kategorije';
$lang['display recently updated albums'] = 'prikaži na novo posodobljene kategorije';
$lang['Recent period'] = 'Novo obdobje';
$lang['Recent photos'] = 'Nove slike';
$lang['display most recent photos'] = 'prikaži najbolj nove slike';
$lang['Redirection...'] = 'Preusmeritev...';
$lang['Please, enter a login'] = 'Prosim, prijavite se';
$lang['login mustn\'t end with a space character'] = 'prijava se ne sme končati s presledkom';
$lang['login mustn\'t start with a space character'] = 'prijava se ne sme začeti s presledkom';
$lang['this login is already used'] = 'ta uporabnik je že prijavljen';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-mail mora biti oblike xxx@yyy.eee (primer : jack@altern.org)';
$lang['please enter your password again'] = 'prosim vnesite svoje geslo še enkrat';
$lang['Auto login'] = 'Avtomatska prijava';
$lang['remove this tag from the list'] = 'odstrani značko iz seznama';
$lang['representative'] = 'reprezentativen';
$lang['Search for Author'] = 'Iskanje po avtorju';
$lang['Search in albums'] = 'Iskanje po kategorijah';
$lang['Search by Date'] = 'Iskanje po datumo';
$lang['Date'] = 'Datum';
$lang['End-Date'] = 'Končni datum';
$lang['Kind of date'] = 'Oblika datuma';
$lang['Search for words'] = 'Iskanje po besedah';
$lang['Search for all terms'] = 'Iskanje po vseh izrazih';
$lang['Search for any terms'] = 'Iskanje po kateremkoli izrazu';
$lang['Empty query. No criteria has been entered.'] = 'Prazen niz. Vnesen ni bil niti eden kriterij.';
$lang['Search Options'] = 'Nastavitve iskanja';
$lang['Search results'] = 'Rezultat iskanja';
$lang['Search in sub-albums'] = 'Iskanje po podkategorijah';
$lang['searched words : %s'] = 'iskalne besede : %s';
$lang['Contact'] = 'Kontakt';
$lang['set as album representative'] = 'set as category representative';
$lang['Maximum width must be a number superior to 50'] = 'Maksimalna dolžina mora biti večje od 50';
$lang['display a calendar by creation date'] = 'prikaži kolendar po datumo nastanka';
$lang['display all photos in all sub-albums'] = 'prikaži vse elemente v kategorijah in pod-kategorijah';
$lang['return to normal view mode'] = 'vrni se v normalni način';
$lang['display a calendar by posted date'] = 'prikaži kolendar po datumo odpošiljanja';
$lang['Show number of comments'] = 'Prikaži število komentarjev';
$lang['Show number of hits'] = 'Prikaži število zadetkov';
$lang['slideshow'] = 'diaprojekcija';
$lang['stop the slideshow'] = 'ustavi diaprojekcijo';
$lang['Specials'] = 'Posebno';
$lang['SQL queries in'] = 'SQL povpraševanje v';
$lang['display only recently posted photos'] = 'prikaži samo zadnje odposlane slike';
$lang['return to the display of all photos'] = 'vrni se v prikaz vseh slik';
$lang['the beginning'] = 'začetek';
$lang['Interface theme'] = 'Tema';
$lang['Thumbnails'] = 'Predogled';
$lang['Menu'] = 'Meni';
$lang['A comment on your site'] = 'Komentar na vaši strani';
$lang['today'] = 'danes';
$lang['Update your rating'] = 'Popravi svojo oceno';
$lang['wrong filename'] = 'napačno ime datoteke';
$lang['the username must be given'] = 'potrebno je uporabniško ime';
$lang['useful when password forgotten'] = 'uporabno, v primeru izgubljenega gesla';
$lang['Quick search'] = 'Hitro iskanje';
$lang['Connected user: %s'] = 'Prijavljeni uporabniki: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Brskalnik: %s';
$lang['Author: %s'] = 'Avtor: %s';
$lang['Comment: %s'] = 'Komentar: %s';
$lang['Comment by %s'] = 'Komentar za %s';
$lang['User: %s'] = 'Uporabnik: %s';
$lang['Email: %s'] = 'E-pošta: %s';
$lang['Admin: %s'] = 'Administrator: %s';
$lang['Registration of %s'] = 'Prijavljenih %s';
$lang['Album: %s'] = 'Kategorija: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Nepravilen status uporabnika "guest", uporabljen bo privzeti status. Prosim obvestite skrbnika.';
$lang['this email address is already in use'] = 'email uporablja že drug uporabnik';
$lang['Album results for'] = 'Category results for';
$lang['Tag results for'] = 'Rezultat za značke';
$lang['from %s to %s'] = 'od %s do %s';
$lang['Play of slideshow'] = 'Začni diaprojekcijo';
$lang['Pause of slideshow'] = 'Premor diaprojekcije';
$lang['Repeat the slideshow'] = 'Ponovi diaprojekcijo';
$lang['day'][0] = "nedelja";
$lang['day'][1] = "ponedeljek";
$lang['day'][2] = "torek";
$lang['day'][3] = "sreda";
$lang['day'][4] = "četrtek";
$lang['day'][5] = "petek";
$lang['day'][6] = "sobota";
$lang['month'][10] = "oktober";
$lang['month'][11] = "november";
$lang['month'][12] = "december";
$lang['month'][1] = "januar";
$lang['month'][2] = "februar";
$lang['month'][3] = "marec";
$lang['month'][4] = "april";
$lang['month'][5] = "maj";
$lang['month'][6] = "junij";
$lang['month'][7] = "julij";
$lang['month'][8] = "avgust";
$lang['month'][9] = "september";
$lang['Not repeat the slideshow'] = 'Ne ponovi prezentacije';
$lang['Reduce diaporama speed'] = 'Zmanjšaj hitrost predvajanja';
$lang['Accelerate diaporama speed'] = 'Povečaj hitrost predvajanja';
$lang['Submit'] = 'Pošlji';
$lang['Yes'] = 'Da';
$lang['No'] = 'Ne';
$lang['%d photo'] = '%d slika';
$lang['%d photos'] = '%d slik';
$lang['%d photo is also linked to current tags'] = '%d slika je pravtako povezana s trenutno značko';
$lang['%d photos are also linked to current tags'] = '%d slike so pravtako povezane s trenutnimi značkami';
$lang['display photos linked to this tag'] = 'Pokaži slike vezane na samo to označbo ';
$lang['photos posted during the last %d days'] = 'slike naložene zadnjih  %d dni';
$lang['Piwigo Help'] = 'Piwigo pomoč';
$lang['Rank'] = 'Rang';
$lang['group by letters'] = 'grupiraj po črkah';
$lang['letters'] = 'črke';
$lang['show tag cloud'] = 'show tags cloud';
$lang['cloud'] = 'cloud';
$lang['Reset to default values'] = 'Resetiraj na privzete vrednosti';
$lang['delete all photos from your favorites'] = 'odstrani vse slike iz svojih priljubljenih';
$lang['Sent by'] = 'Poslano od';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Piškotki so blokirani ali niso podprti s strani vašega brskalnika. Za prijavo je potrebno omogočiti piškotke.';
$lang['edit this comment'] = 'uredi ta komentar';
$lang['Edit a comment'] = 'Uredi komentar';
$lang['Are you sure?'] = 'Ali ste prepričani?';
$lang['(!) This comment requires validation'] = '(!) Komentar potrebuje validacijo';
$lang['Welcome'] = 'Dobrodošli';
$lang['Welcome to your Piwigo photo gallery!'] = 'Dobrodošli v svoji Piwigo galeriji!';
$lang['... or browse your empty gallery'] = '... ali prebrskaj svojo prazno galerijo';
$lang['... or please deactivate this message, I will find my way by myself'] = '... ali prosim deaktivirajte to sporočilo , I will find my way by myself';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Zdravo %s, tvoja Piwigo galerija je prazna!';
$lang['I want to add photos'] = 'Želim dodati slike';
$lang['Manage this user comment: %s'] = 'Uredi komentar uporabnika: %s';
$lang['Email address is missing. Please specify an email address.'] = 'Manjka e-pošta. Prosim navedite svojo e-pošto.';
$lang['This author modified following comment:'] = 'Ta uporabnik je uredil naslednji komentar:';
$lang['This author removed the comment with id %d'] = 'Ta uporabnik je odstranil komentar z id-jem %d';
$lang['delete this comment'] = 'odstrani komentar';
$lang['validate this comment'] = 'preveri komentar';
$lang['html tags are not allowed in login'] = 'pri prijavi niso dovoljene html značke';
$lang['%d rates'] = '%d točk';
$lang['Rating score'] = 'Ocena';
$lang['Enter a username or email address'] = 'Vnesite uporabniško ime ali e-pošto';
$lang['Invalid username or email'] = 'Nepravilno uporabniško ime ali e-pošta';
$lang['Password reset is not allowed for this user'] = 'Poenostavite gesla ni možna za tega uporabnika';
$lang['User "%s" has no email address, password reset is not possible'] = 'Uporabnik "%s" nima e-pošte, zato poenostavitev gesla ni možna';
$lang['Someone requested that the password be reset for the following user account:'] = 'Nekdo je zahteval poenostavite gesla za uporabniški račun:';
$lang['Username "%s" on gallery %s'] = 'Uporabnik "%s" za album %s';
$lang['To reset your password, visit the following address:'] = 'Za poenostavitev gesla, obiščite naslednji spletni naslov:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Če je bila to napaka, preprosto prezrite to sporočilo in nič se ne bo zgodilo.';
$lang['Password Reset'] = 'Poenostavitev gesla';
$lang['Check your email for the confirmation link'] = 'Preverite e-pošto za potrditev';
$lang['Invalid key'] = 'Nepravilen ključ';
$lang['The passwords do not match'] = 'Gesli se ne ujemata';
$lang['Your password has been reset'] = 'Vaše geslo je bilo poenostavljeno';
$lang['Return to home page'] = 'Vrnite se na domačo stran';
$lang['Please enter your username or email address.'] = 'Prosim vnesite svoje uporabniško ime ali e-pošto.';
$lang['You will receive a link to create a new password via email.'] = 'Po e-pošti boste prejeli povezavo za kreiranje novega gesla.';
$lang['Username or email'] = 'Uporabniško ime ali e-pošta';
$lang['Change my password'] = 'Spremeni geslo';
$lang['Enter your new password below.'] = 'Vnesite novo geslo.';
$lang['Reset Password'] = 'Poenostavi geslo';
$lang['EXIF Metadata'] = 'EXIF metapodatki';
$lang['IPTC Metadata'] = 'IPTC metapodatki';

?>